# Color-name

Tells you what name a color has

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see [releases](https://github.com/tvanderplas/color-name/releases). 

## Authors

* **Tim Vanderplas** - *Initial work* - [tvanderplas](https://github.com/tvanderplas)
